@@ -788,9 +788,7 @@ void
 ContentXml::writeCell(const QDate &date, const QString &annotation)
 {
 
-  QDateTime dateTime(date);
-
-  writeCell(dateTime, annotation);
+  writeCell(date.startOfDay(), annotation);
 }
 
 void
