@@ -19,7 +19,7 @@
 
 #include "metaxml.h"
 #include "stylesxml.h"
-#include <quazip5/quazipfile.h>
+#include <quazipfile.h>
 
 QHash<QString, QString> *StylesXml::_p_hashNamespaceURI =
   new QHash<QString, QString>();
