@@ -210,8 +210,7 @@ TEST_CASE("Test ODS metadata bug files.", "[odsbug]")
             "metadata_template.ods ::.."
          << endl;
     MetadataOdsReader handler;
-    QFile xicfile(
-      QString(CMAKE_SOURCE_DIR).append("/test/data/metadata_template.ods"));
+    QFile xicfile(QString(CMAKE_SOURCE_DIR).append("/test/data/metadata_template.ods"));
     OdsDocReader xicfile_reader(handler);
     REQUIRE_NOTHROW(xicfile_reader.parse(&xicfile));
 
@@ -231,7 +230,7 @@ TEST_CASE("Test ODS files.", "[ods]")
 
     cout << endl << "..:: read ODS file xic.ods ::.." << endl;
     CustomHandlerXic handler;
-    QFile xicfile(QString(CMAKE_SOURCE_DIR).append("/test/data/xic.ods"));
+    QFile xicfile(QString("../").append("/test/data/xic.ods"));
     OdsDocReader xicfile_reader(handler);
     REQUIRE_NOTHROW(xicfile_reader.parse(&xicfile));
 
