@@ -142,7 +142,7 @@ main([[maybe_unused ]] int argc, [[maybe_unused ]] char **argv)
   qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
   QFile file(QString(CMAKE_SOURCE_DIR).append("/test/data/xic.ods"));
   if(!file.open(QIODevice::ReadOnly))
-    return 1;
+    qFatal() << "Failed to open file" << file.fileName();
 
 
   while(readZipHeaderBuffer(&file, "content") == false)
